==> haskell-text-rope-0.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-8PHmwYLjGSrCvCPnb4yiqh
key:                  text-rope-0.3-8PHmwYLjGSrCvCPnb4yiqh
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  acf42136c6070ddae34b434286f5fbb4
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-8PHmwYLjGSrCvCPnb4yiqh
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.1.0-DtCykb5ubgAP5TmqHJqsZ

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-rope-0.3-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-F1LXs9gUtwd1w4Z7YO5k0x
key:                  text-rope-0.3-F1LXs9gUtwd1w4Z7YO5k0x
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  84b1b7a7bd7089e0f47fea4e5bbd6f4e
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-F1LXs9gUtwd1w4Z7YO5k0x
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.1.0-GCmMsLcrTyFGJ15LkY6umX

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
